#
# spec file for package python-mautrix
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%bcond_without test
%else
# Leap 15.x: Ignore that upstream doesn't support Python < 3.8 and does not have the test requirements
%define skip_python2 1
%bcond_with test
%endif

Name:           python-mautrix
Version:        0.17.8
Release:        bp155.1.5
Summary:        A Python 3 asyncio Matrix framework
License:        MPL-2.0
URL:            https://github.com/mautrix/python
# The GitHub Archive has json data required for the test suite
Source:         https://github.com/mautrix/python/archive/refs/tags/v%{version}.tar.gz#/mautrix-python-%{version}-gh.tar.gz
BuildRequires:  %{python_module base}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-aiohttp >= 3
Requires:       python-attrs >= 18.1.0
Requires:       python-yarl >= 1
Suggests:       python-python-magic >= 0.4.15
BuildArch:      noarch
BuildRequires:  %{python_module aiohttp >= 3.0.1}
BuildRequires:  %{python_module attrs >= 18.1.0}
BuildRequires:  %{python_module yarl >= 1}
# SECTION optional requirements
BuildRequires:  %{python_module python-magic >= 0.4.15}
# /SECTION optional requirements
%if %{with test}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module asyncpg}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module aiosqlite}
BuildRequires:  %{python_module sqlalchemy}
BuildRequires:  %{python_module olm}
BuildRequires:  %{python_module unpaddedbase64}
BuildRequires:  %{python_module pycryptodomex}
%endif
%python_subpackages

%description
A Python 3 asyncio Matrix framework.

%prep
%setup -q -n python-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
%pytest
%endif

%files %{python_files}
%doc README.rst CHANGELOG.md
%license LICENSE
%{python_sitelib}/mautrix
%{python_sitelib}/mautrix-%{version}*-info

%changelog
* Wed Aug 31 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.17.8:
  - (crypto) Fixed parsing /keys/claim responses with no failures
    field.
  - (bridge) Fixed parsing e2ee key sharing allow/minimum level
    config.
  - (util.async_db) Added init_commands to run commands on
    each SQLite connection (e.g. to enable PRAGMAs). No-op on
    Postgres.
  - (bridge) Added check to make sure e2ee keys are intact on
    server. If they aren't, the crypto database will be wiped and
    the bridge will stop.
  - (bridge) Added hidden option to use appservice login for
    double puppeting.
  - (client) Fixed sync handling throwing an error if event
    parsing failed.
  - (errors) Added M_UNKNOWN_ENDPOINT error code from MSC3743
  - (appservice) Updated MSC3202 support to handle one time keys
    correctly.
  - (types) Added m.read.private to receipt types.
  - (appservice) Stopped ensure_registered and invite_user
    raising IntentErrors (now they raise the original Matrix
    error instead).
  - (bridge) Started rejecting reusing access tokens when
    enabling double puppeting. Reuse is detected by presence of
    encryption keys on the device.
  - (client.api) Added wrapper method for the /context API.
  - (api, errors) Implemented new error codes from MSC3848.
  - (types) Disabled deserializing m.direct content (it didn't
    work and it wasn't really necessary).
  - (client.state_store) Updated set_encryption_info to allow raw
    dicts. This fixes the bug where sending a m.room.encryption
    event with a raw dict as the content would throw an error
    from the state store.
  - (crypto) Fixed error when fetching keys for user with no
    cross-signing keys (thanks to @maltee1 in #109).
  - (types) Updated BeeperMessageStatusEventContent fields.
  - (api) Updated request logging to log full URL instead of only
    path.
  - (bridge) Fixed migrating key sharing allow flag to new config
    format.
  - (appservice) Added beeper_new_messages flag for batch_send
    method.
  - (crypto) Fixed Python 3.8/9 compatibility broken in v0.17.0.
  - (crypto) Added some tests for attachments and store code.
  - (crypto) Improved logging when device change validation
    fails.
  - Breaking change (bridge) Added options to check cross-signing
    status for bridge users. This requires changes to the base
    config.
    New options include requiring cross-signed devices (with
    TOFU) for sending and/or receiving messages, and an
    option to drop any unencrypted messages.
  - Breaking change (crypto) Removed sender_key parameter from
    CryptoStore's has_group_session and put_group_session, and
    also OlmMachine's wait_for_session.
  - Breaking change (crypto.store.memory) Updated the key of the
    _inbound_sessions dict to be (room_id, session_id), removing
    the identity key in the middle. This only affects custom
    stores based on the memory store.
  - (crypto) Added basic cross-signing validation code.
  - (crypto) Marked device_id and sender_key as deprecated in
    Megolm events as per Matrix 1.3.
  - (api) Bumped request logs to DEBUG level.
    Also added new sensitive parameter to the request method
    to prevent logging content in sensitive requests. The
    login method was updated to mark the content as sensitive if a
    password or token is provided.
  - (bridge.commands) Switched the order of the user ID parameter
    in set-pl, set-avatar and set-displayname.
  - (bridge) Started requiring Matrix v1.1 support from
    homeservers.
  - (bridge) Added hack to automatically send a read receipt for
    messages sent to Matrix with double puppeting (to work around
    weird unread count issues).
  - (client) Added support for knocking on rooms (thanks to
    @maltee1 in #105).
  - (bridge) Added config option to set key rotation settings
    with e2be.
  - (bridge) Updated e2be helper to stop bridge if syncing fails.
  - (util.async_db) Updated asyncpg connector to stop program
    if an asyncpg InternalClientError is thrown. These errors
    usually cause everything to get stuck.
    The behavior can be disabled by passing meow_exit_on_ice
    = false in the db_args.
* Tue Jun 21 2022 Ben Greiner <code@bnavigator.de>
- Enable test suite for TW. The do have one.
  * Update test requirements.
  * Skip tests on Leap, async packages not available.
* Tue Jun 21 2022 Matej Cepl <mcepl@suse.com>
- Update to 0.16.8:
  Complete log is included as CHANGELOG.md, but it has been too
  long since we have updated last time.
* Wed Jun  9 2021 Sasi Olin <hel@lcp.world>
- Update to 0.9.3:
  - Switched to stable space prefixes.
  - Added option to send arbitrary content with membership events.
  - Added warning if media encryption dependencies aren't installed.
  - Added support for pycryptodomex for media encryption.
  - Added utilities for pushing bridge status to an arbitrary HTTP endpoint.
  - Changed update_direct_chats bridge method to only send updated m.direct data if the content was modified.
  - Added type classes for VoIP.
  - Added methods for modifying push rules and room tags.
  - Switched to asyncio.create_task everywhere (replacing the older loop.create_task and asyncio.ensure_future).
  - Added option to retry all HTTP requests when encountering a HTTP network error or gateway error response (502/503/504)
  - Disabled by default, you need to set the default_retry_count field in HTTPAPI (or Client), or the default_http_retry_count field in AppService to enable.
  - Can also be enabled with HTTPAPI.request()s retry_count parameter.
  - The mautrix.util.network_retry module was removed as it became redundant.
  - Fixed GET requests having a body (#44).
* Tue Mar 16 2021 Matej Cepl <mcepl@suse.com>
- Update to version 0.8.15:
  - Add option to not use transaction for db upgrades
  - Return None instead of attr.NOTHING for fields without value
  - Crash if server doesn't advertise appservice login
  - Switch BaseFileConfig to use pkgutil instead of pkg_resources
  - Catch MNotFound when updating m.direct
  - Log data when deserialization fails
  - Expose ExtensibleEnum in mautrix.types
  - Allow postgresql:// scheme in encryption database URL
  - Add better error message if deserialization fails
  - Log full data instead of only known fields when failing to
    deserialize
  - Automatically retry login if custom puppet start fails
  - Fix ExtensibleEnum leaking keys between different types
  - Allow changing bot used in ensure_joined
  - Add custom puppet relogin when sync fails
  - Handle MNotFound when getting pinned events
  - Use same txn_id when retrying sends in bridges
  - Update client state store with events from sync
  - Don't check message in whoami forbidden error
  - Fix fault for rooms without power_levels state event.
  - Graceful handling of missing or empty event.unsigned object.
  - Send warning when receiving encrypted messages with e2be
    disabled
  - Add utility for async getter locking
  - Allow overriding asyncpg pool in async_db Database wrapper
  - Only update state if state_store is set
* Mon Jan  4 2021 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.6:
  * Switched to secrets.token_urlsafe for generating tokens
    (e.g. registration hs/as_tokens).
  * Changed sync error logging to warning instead of exception.
  * Allowed sending read receipts even if appservice user is not
    in room (#34).
* Tue Dec 29 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.5:
  * Made SerializableEnum work with int value
  * Added TraceLogger type hints to command handling classes
* Thu Nov 19 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.8.3:
  * Fixed typo in HTML reply fallback generation when target
    message is plaintext.
  * Made CommandEvent.mark_read async instead of returning an
    awaitable, because sometimes it didn't return an awaitable.
* Wed Jun  3 2020 Dead Mozay <dead_mozay@opensuse.org>
- Update to version 0.5.0:
  * No changelog was made available.
* Fri Feb 28 2020 Tomáš Chvátal <tchvatal@suse.com>
- Format with spec-cleaner
- Sort out the deps
* Thu Feb 27 2020 Dead Mozay <dead_mozay@opensuse.org>
- Initial package
